'use strict';

var _Promise = require('babel-runtime/core-js/promise')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports.getTimeCardData = getTimeCardData;
exports.writeTimeCard = writeTimeCard;
exports.blankTimecard = blankTimecard;
exports.checkForValidTimecard = checkForValidTimecard;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _pendel = require('pendel');

var _pendel2 = _interopRequireDefault(_pendel);

var _lodashSortby = require('lodash.sortby');

var _lodashSortby2 = _interopRequireDefault(_lodashSortby);

var _happyJson = require('happy-json');

var _happyJson2 = _interopRequireDefault(_happyJson);

var _messagesJs = require('./messages.js');

// help node 0.10 with Promises
require('native-promise-only');

/**
 * Read the json file with the timecard data and set Timecard state.
 *
 * @returns {*} Promise
 */

function getTimeCardData() {
	var self = this;

	return new _Promise(function (resolve, reject) {
		_fs2['default'].readFile(self.filepath, 'utf8', function (err, data) {
			if (err) {
				reject(err);
			} else {
				self.timecardData = JSON.parse(data);
				self.name = self.timecardData.name;
				var shifts = self.timecardData.shifts;

				// reset to zero each time the timecard data is read
				self.totalSeconds = 0;

				if (shifts.length > 0) {
					self.shifts = (0, _lodashSortby2['default'])(shifts, function (shift) {
						return shift.id;
					});

					var lastShift = self.shifts[self.shifts.length - 1];
					if (lastShift.hasOwnProperty('startTime') && lastShift.hasOwnProperty('endTime') === false) {
						self.clockoutIsPending = true;
						self.pendingClockoutIndex = lastShift.id;
					}
					self.shifts.map(function (item) {
						if (item.hasOwnProperty('startTime') && item.hasOwnProperty('endTime')) {
							self.totalSeconds += (0, _pendel2['default'])(item.startTime, item.endTime).totalSeconds;
						}
					});
					resolve(self.shifts);
				} else {
					self.shifts = [];
					resolve(self.timecardData);
				}
			}
		});
	});
}

/**
 * Physically write the timecard data to the json file.
 *
 * @param {object} data - the json data to write
 */

function writeTimeCard(data) {
	var self = this;

	return new _Promise(function (resolve, reject) {
		_fs2['default'].writeFile(self.filepath, data, function (err) {
			if (err) {
				reject(err);
			}
			resolve();
		});
	});
}

/**
 * The blank .timecard.json value.
 */

function blankTimecard(name) {
	return '{\n  "project": "' + name + '",\n  "shifts": [],\n  "totals": {\n    "hours": 0,\n    "minutes": 0,\n    "seconds": 0\n  }\n}';
}

/**
 * Check if .timecard.json is in a valid json format.
 */

function checkForValidTimecard() {
	try {
		var timecardData = require('../.timecard.json');

		if ((0, _happyJson2['default'])(timecardData) === false) {
			throw new Error('Invalid timecard data.');
		}
	} catch (err) {
		console.log(_messagesJs.errors.invalidTimeCardJSON);
		console.log('  ' + err);
		process.exit(1);
	}
}